[EGIT] [core/efl] master 01/01: ecore_evas extn module - fix coverity complaint

2015-04-20 Thread Carsten Haitzler
raster pushed a commit to branch master.

http://git.enlightenment.org/core/efl.git/commit/?id=39bbfc30300d4d1368f00bb64162de9493e7d1ba

commit 39bbfc30300d4d1368f00bb64162de9493e7d1ba
Author: Carsten Haitzler (Rasterman) ras...@rasterman.com
Date:   Tue Apr 21 10:19:28 2015 +0900

ecore_evas extn module - fix coverity complaint

coverity is right. CID 1295139 fixed here. tmpstr_free on sometimes
uninitialized local var.
---
 src/modules/ecore_evas/engines/extn/ecore_evas_extn_buf.c | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/src/modules/ecore_evas/engines/extn/ecore_evas_extn_buf.c 
b/src/modules/ecore_evas/engines/extn/ecore_evas_extn_buf.c
index 9026615..5e21114 100644
--- a/src/modules/ecore_evas/engines/extn/ecore_evas_extn_buf.c
+++ b/src/modules/ecore_evas/engines/extn/ecore_evas_extn_buf.c
@@ -19,7 +19,7 @@ _extnbuf_new(const char *base, int id, Eina_Bool sys, int num,
char file[PATH_MAX];
mode_t mode = S_IRUSR | S_IWUSR;
int page_size;
-   Eina_Tmpstr *tmp;
+   Eina_Tmpstr *tmp = NULL;
 
page_size = eina_cpu_page_size();
 

-- 




[EGIT] [core/enlightenment] master 01/01: Fix wayland compositor on 32 bit systems

2015-04-20 Thread Derek Foreman
discomfitor pushed a commit to branch master.

http://git.enlightenment.org/core/enlightenment.git/commit/?id=1fb1f17db010c575eae32960da84d3fbfab13119

commit 1fb1f17db010c575eae32960da84d3fbfab13119
Author: Derek Foreman der...@osg.samsung.com
Date:   Mon Apr 20 18:17:55 2015 -0400

Fix wayland compositor on 32 bit systems

Summary:
_e_elm_win_trap_show() treats Ecore_Window as a 64bit data type when
it's actually the same size as the system's pointer type.

 #24HourFullPowerNoToiletNoShower

Reviewers: devilhorns, zmike

Subscribers: cedric

Differential Revision: https://phab.enlightenment.org/D2388

fix T2194
---
 configure.ac|  5 -
 src/bin/e_win.c | 20 +---
 2 files changed, 17 insertions(+), 8 deletions(-)

diff --git a/configure.ac b/configure.ac
index 6cbbeea..c29d9ba 100644
--- a/configure.ac
+++ b/configure.ac
@@ -443,7 +443,6 @@ test -n $dbus_mount  
AC_DEFINE_UNQUOTED([HAVE_UDISKS_MOUNT], [1], [enable Ud
 AM_CONDITIONAL([HAVE_UDISKS_MOUNT], [test -n $dbus_mount])
 AM_CONDITIONAL([HAVE_EEZE_MOUNT], [test -n $eeze_mount])
 
-AC_CHECK_SIZEOF([void*])
 # verify wayland-only early to adapt dependencies
 
 have_wayland_only=no
@@ -842,10 +841,6 @@ if test x${have_wayland} = xyes; then
   fi
 fi
 
-if test x${have_wayland} = xyes  test $ac_cv_sizeof_voidp -ne 8 ; then
-   AC_MSG_ERROR([wayland support is only available for 64bit architectures])
-fi
-
 AM_CONDITIONAL([HAVE_WAYLAND], [test x${have_wayland} = xyes])
 AM_CONDITIONAL([HAVE_WAYLAND_ONLY], [test x${have_wayland_only} = xyes])
 AM_CONDITIONAL([HAVE_WAYLAND_CLIENTS], [test x${have_wayland_clients} = 
xyes])
diff --git a/src/bin/e_win.c b/src/bin/e_win.c
index 8797c67..c13c229 100644
--- a/src/bin/e_win.c
+++ b/src/bin/e_win.c
@@ -67,6 +67,9 @@ _e_elm_win_trap_show(void *data, Evas_Object *o)
  {
 E_Client *ec;
 Ecore_Window win;
+#ifdef HAVE_WAYLAND
+uint64_t wl_win_id;
+#endif
 E_Pixmap_Type type = E_PIXMAP_TYPE_X;
 
 win = elm_win_window_id_get(o);
@@ -76,7 +79,7 @@ _e_elm_win_trap_show(void *data, Evas_Object *o)
  type = E_PIXMAP_TYPE_WL;
  ctx-pointer = e_comp-pointer;
  elm_win_borderless_set(o, 1);
- win = e_comp_wl_id_get(win, getpid());
+ wl_win_id = e_comp_wl_id_get(win, getpid());
   }
 else
 #endif
@@ -85,7 +88,12 @@ _e_elm_win_trap_show(void *data, Evas_Object *o)
  ctx-pointer = e_pointer_window_new(win, EINA_TRUE);
   }
 
-ec = e_pixmap_find_client(type, win);
+#ifdef HAVE_WAYLAND
+if (type == E_PIXMAP_TYPE_WL)
+  ec = e_pixmap_find_client(type, wl_win_id);
+else
+#endif
+  ec = e_pixmap_find_client(type, win);
 if (ec)
   ctx-client = ec;
 else
@@ -101,7 +109,13 @@ _e_elm_win_trap_show(void *data, Evas_Object *o)
  if ((!title) || (!title[0]))
title = E;
  ecore_evas_title_set(ee, title);
- cp = e_pixmap_new(type, win);
+
+#ifdef HAVE_WAYLAND
+ if (type == E_PIXMAP_TYPE_WL)
+   cp = e_pixmap_new(type, wl_win_id);
+ else
+#endif
+   cp = e_pixmap_new(type, win);
  EINA_SAFETY_ON_NULL_RETURN_VAL(cp, EINA_TRUE);
 
  ctx-client = e_client_new(cp, 0, 1);

-- 




[EGIT] [core/enlightenment] master 01/02: e - xsettings - calloc buffer since we leave 3 of 4 bytes unset

2015-04-20 Thread Carsten Haitzler
raster pushed a commit to branch master.

http://git.enlightenment.org/core/enlightenment.git/commit/?id=c746beb2023948f1a26022872e6d8386a3bc6317

commit c746beb2023948f1a26022872e6d8386a3bc6317
Author: Carsten Haitzler (Rasterman) ras...@rasterman.com
Date:   Tue Apr 21 08:52:19 2015 +0900

e - xsettings - calloc buffer since we leave 3 of 4 bytes unset

the first 4 bytes is a msb/lsb thing for xsetttings - we ignore 3 of
the 4 bytes. thus we should just calloc the whole buffer to ensure its 0
---
 src/bin/e_xsettings.c | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/src/bin/e_xsettings.c b/src/bin/e_xsettings.c
index 42db400..1354535 100644
--- a/src/bin/e_xsettings.c
+++ b/src/bin/e_xsettings.c
@@ -334,7 +334,7 @@ _e_xsettings_apply(Settings_Manager *sm)
EINA_LIST_FOREACH(settings, l, s)
  len += s-length;
 
-   pos = data = malloc(len);
+   pos = data = calloc(1, len);
if (!data) return;
 
 #if __BYTE_ORDER == __LITTLE_ENDIAN

-- 




[EGIT] [core/enlightenment] master 02/02: e client - desk wait - ref it properly and clean up delfn

2015-04-20 Thread Carsten Haitzler
raster pushed a commit to branch master.

http://git.enlightenment.org/core/enlightenment.git/commit/?id=665caad451c7184bb85b85067c491d15d3dfc1ea

commit 665caad451c7184bb85b85067c491d15d3dfc1ea
Author: Carsten Haitzler (Rasterman) ras...@rasterman.com
Date:   Tue Apr 21 09:36:33 2015 +0900

e client - desk wait - ref it properly and clean up delfn

delfn's on desks being referred to as profile.wait_desk were never
cleared when client was freed. als the desk itself never got an obj
reference - fix that and ref/unref it.
---
 src/bin/e_client.c | 19 ++-
 1 file changed, 18 insertions(+), 1 deletion(-)

diff --git a/src/bin/e_client.c b/src/bin/e_client.c
index ea23a0c..f216523 100644
--- a/src/bin/e_client.c
+++ b/src/bin/e_client.c
@@ -187,10 +187,13 @@ _e_client_desk_window_profile_wait_desk_delfn(void *data, 
void *obj)
const char *p;
int i;
 
+   printf(DELFN %p\n, ec);
if (e_object_is_del(E_OBJECT(ec))) return;
 
ec-e.state.profile.wait_desk_delfn = NULL;
eina_stringshare_replace(ec-e.state.profile.wait, NULL);
+   if (ec-e.state.profile.wait_desk)
+ e_object_unref(E_OBJECT(ec-e.state.profile.wait_desk));
ec-e.state.profile.wait_desk = NULL;
ec-e.state.profile.wait_for_done = 0;
 
@@ -528,6 +531,14 @@ _e_client_free(E_Client *ec)
 
e_hints_client_list_set();
evas_object_del(ec-frame);
+   if (ec-e.state.profile.wait_desk)
+ {
+e_object_delfn_del(E_OBJECT(ec-e.state.profile.wait_desk),
+   ec-e.state.profile.wait_desk_delfn);
+ec-e.state.profile.wait_desk_delfn = NULL;
+e_object_unref(E_OBJECT(ec-e.state.profile.wait_desk));
+ }
+   ec-e.state.profile.wait_desk = NULL;
free(ec);
 }
 
@@ -2581,15 +2592,21 @@ e_client_desk_window_profile_wait_desk_set(E_Client 
*ec, E_Desk *desk)
 ec-e.state.profile.wait_desk_delfn = NULL;
  }
 
+   if (ec-e.state.profile.wait_desk)
+ e_object_unref(E_OBJECT(ec-e.state.profile.wait_desk));
+   ec-e.state.profile.wait_desk = NULL;
+
if (desk)
  {
+printf(ADD DELFN to %p\n, desk);
 ec-e.state.profile.wait_desk_delfn =
e_object_delfn_add(E_OBJECT(desk),
   _e_client_desk_window_profile_wait_desk_delfn,
   ec);
  }
-
ec-e.state.profile.wait_desk = desk;
+   if (ec-e.state.profile.wait_desk)
+ e_object_ref(E_OBJECT(ec-e.state.profile.wait_desk));
 }
 
 EAPI void

-- 




[EGIT] [core/efl] master 01/02: Edje: Remove non-sensical NULL check

2015-04-20 Thread Jean-Philippe ANDRÉ
jpeg pushed a commit to branch master.

http://git.enlightenment.org/core/efl.git/commit/?id=a25346844206412941364b11e0c60242d9701a43

commit a25346844206412941364b11e0c60242d9701a43
Author: Jean-Philippe Andre jp.an...@samsung.com
Date:   Mon Apr 20 17:57:11 2015 +0900

Edje: Remove non-sensical NULL check

Fixes CID 1261450
---
 src/bin/edje/edje_cc_handlers.c | 1 -
 1 file changed, 1 deletion(-)

diff --git a/src/bin/edje/edje_cc_handlers.c b/src/bin/edje/edje_cc_handlers.c
index dcb41a8..41da0f2 100644
--- a/src/bin/edje/edje_cc_handlers.c
+++ b/src/bin/edje/edje_cc_handlers.c
@@ -13052,7 +13052,6 @@ edje_cc_handlers_wildcard(void)
 end = strrchr(last, '.');
 if (end) last = end + 1;
  }
-   if (!last) return EINA_FALSE;
if (current_part)
  {
 if ((!strcmp(last, part))  (!current_part-name))

-- 




[EGIT] [core/elementary] master 01/01: elm: add safety check

2015-04-20 Thread Jaeun Choi
eunue pushed a commit to branch master.

http://git.enlightenment.org/core/elementary.git/commit/?id=f1ae9c16b3a6610c18efbc583cf27e5d637fee4a

commit f1ae9c16b3a6610c18efbc583cf27e5d637fee4a
Author: Jaeun Choi jaeun12.c...@samsung.com
Date:   Tue Apr 21 14:30:41 2015 +0900

elm: add safety check

when insert a new item before/after an item, the relative item should not 
be NULL.
this patch fixes naviframe, gengrid, genlist, list, and toolbar.

@fix
---
 src/lib/elc_naviframe.c | 3 +++
 src/lib/elm_gengrid.c   | 2 ++
 src/lib/elm_genlist.c   | 2 ++
 src/lib/elm_list.c  | 2 ++
 src/lib/elm_toolbar.c   | 2 ++
 5 files changed, 11 insertions(+)

diff --git a/src/lib/elc_naviframe.c b/src/lib/elc_naviframe.c
index 9d2b7c5..b14d203 100644
--- a/src/lib/elc_naviframe.c
+++ b/src/lib/elc_naviframe.c
@@ -1570,6 +1570,8 @@ _elm_naviframe_item_insert_before(Eo *obj, 
Elm_Naviframe_Data *sd, Elm_Object_It
 {
Elm_Object_Item *eo_it;
Elm_Naviframe_Item_Data *prev_it = NULL;
+
+   EINA_SAFETY_ON_NULL_RETURN_VAL(eo_before, NULL);
ELM_NAVIFRAME_ITEM_DATA_GET(eo_before, before);
 
ELM_NAVIFRAME_ITEM_CHECK_OR_RETURN(before, NULL);
@@ -1604,6 +1606,7 @@ _elm_naviframe_item_insert_after(Eo *obj, 
Elm_Naviframe_Data *sd, Elm_Object_Ite
Elm_Object_Item *eo_item;
Eina_Bool top_inserted = EINA_FALSE;
 
+   EINA_SAFETY_ON_NULL_RETURN_VAL(eo_after, NULL);
ELM_NAVIFRAME_ITEM_DATA_GET(eo_after, after);
 
ELM_NAVIFRAME_ITEM_CHECK_OR_RETURN(after, NULL);
diff --git a/src/lib/elm_gengrid.c b/src/lib/elm_gengrid.c
index 9a4937e..f22886e 100644
--- a/src/lib/elm_gengrid.c
+++ b/src/lib/elm_gengrid.c
@@ -3942,6 +3942,7 @@ _elm_gengrid_item_insert_before(Eo *obj, Elm_Gengrid_Data 
*sd, const Elm_Gengrid
 {
Elm_Gen_Item *it;
Eina_Inlist *tmp;
+   EINA_SAFETY_ON_NULL_RETURN_VAL(eo_relative, NULL);
ELM_GENGRID_ITEM_DATA_GET(eo_relative, relative);
 
ELM_GENGRID_ITEM_CHECK_OR_RETURN(relative, NULL);
@@ -3969,6 +3970,7 @@ _elm_gengrid_item_insert_after(Eo *obj, Elm_Gengrid_Data 
*sd, const Elm_Gengrid_
 {
Elm_Gen_Item *it;
Eina_Inlist *tmp;
+   EINA_SAFETY_ON_NULL_RETURN_VAL(eo_relative, NULL);
ELM_GENGRID_ITEM_DATA_GET(eo_relative, relative);
 
ELM_GENGRID_ITEM_CHECK_OR_RETURN(relative, NULL);
diff --git a/src/lib/elm_genlist.c b/src/lib/elm_genlist.c
index 18faf44..17fa6d3 100644
--- a/src/lib/elm_genlist.c
+++ b/src/lib/elm_genlist.c
@@ -6077,6 +6077,7 @@ _elm_genlist_item_prepend(Eo *obj EINA_UNUSED, 
Elm_Genlist_Data *sd, const Elm_G
 EOLIAN static Elm_Object_Item*
 _elm_genlist_item_insert_after(Eo *obj EINA_UNUSED, Elm_Genlist_Data *sd, 
const Elm_Genlist_Item_Class *itc, const void *data, Elm_Object_Item 
*eo_parent, Elm_Object_Item *eo_after, Elm_Genlist_Item_Type type, 
Evas_Smart_Cb func, const void *func_data)
 {
+   EINA_SAFETY_ON_NULL_RETURN_VAL(eo_after, NULL);
ELM_GENLIST_ITEM_DATA_GET(eo_after, after);
Elm_Gen_Item *it;
 
@@ -6126,6 +6127,7 @@ _elm_genlist_item_insert_after(Eo *obj EINA_UNUSED, 
Elm_Genlist_Data *sd, const
 EOLIAN static Elm_Object_Item*
 _elm_genlist_item_insert_before(Eo *obj, Elm_Genlist_Data *sd, const 
Elm_Genlist_Item_Class *itc, const void *data, Elm_Object_Item *eo_parent, 
Elm_Object_Item *eo_before, Elm_Genlist_Item_Type type, Evas_Smart_Cb func, 
const void *func_data)
 {
+   EINA_SAFETY_ON_NULL_RETURN_VAL(eo_before, NULL);
ELM_GENLIST_ITEM_DATA_GET(eo_before, before);
Elm_Gen_Item *it;
 
diff --git a/src/lib/elm_list.c b/src/lib/elm_list.c
index 8be1ab2..d7db7da 100644
--- a/src/lib/elm_list.c
+++ b/src/lib/elm_list.c
@@ -2846,6 +2846,7 @@ EOLIAN static Elm_Object_Item*
 _elm_list_item_insert_before(Eo *obj, Elm_List_Data *sd, Elm_Object_Item 
*eo_before, const char *label, Evas_Object *icon, Evas_Object *end, 
Evas_Smart_Cb func, const void *data)
 {
Elm_List_Item_Data *it;
+   EINA_SAFETY_ON_NULL_RETURN_VAL(eo_before, NULL);
ELM_LIST_ITEM_DATA_GET(eo_before, before_it);
 
ELM_LIST_ITEM_CHECK_OR_RETURN(before_it, NULL);
@@ -2867,6 +2868,7 @@ EOLIAN static Elm_Object_Item*
 _elm_list_item_insert_after(Eo *obj, Elm_List_Data *sd, Elm_Object_Item 
*eo_after, const char *label, Evas_Object *icon, Evas_Object *end, 
Evas_Smart_Cb func, const void *data)
 {
Elm_List_Item_Data *it;
+   EINA_SAFETY_ON_NULL_RETURN_VAL(eo_after, NULL);
ELM_LIST_ITEM_DATA_GET(eo_after, after_it);
 
ELM_LIST_ITEM_CHECK_OR_RETURN(after_it, NULL);
diff --git a/src/lib/elm_toolbar.c b/src/lib/elm_toolbar.c
index c588e36..93e1b25 100644
--- a/src/lib/elm_toolbar.c
+++ b/src/lib/elm_toolbar.c
@@ -2987,6 +2987,7 @@ _elm_toolbar_item_insert_before(Eo *obj, Elm_Toolbar_Data 
*sd, Elm_Object_Item *
Elm_Toolbar_Item_Data *it;
double scale;
 
+   EINA_SAFETY_ON_NULL_RETURN_VAL(eo_before, NULL);
ELM_TOOLBAR_ITEM_DATA_GET(eo_before, _before);
ELM_TOOLBAR_ITEM_CHECK_OR_RETURN(_before,  NULL);
 
@@ -3010,6 +3011,7 @@ _elm_toolbar_item_insert_after(Eo *obj, Elm_Toolbar_Data 
*sd, Elm_Object_Item *e

[EGIT] [core/elementary] master 01/01: doc: improve ambigious doc descriptions.

2015-04-20 Thread ChunEon Park
hermet pushed a commit to branch master.

http://git.enlightenment.org/core/elementary.git/commit/?id=93c22704356574224a66468edeab5cdb1af50280

commit 93c22704356574224a66468edeab5cdb1af50280
Author: ChunEon Park her...@hermet.pe.kr
Date:   Tue Apr 21 11:54:07 2015 +0900

doc: improve ambigious doc descriptions.

even descriptions weren't matched each other.
---
 src/lib/elm_gengrid.eo  | 2 +-
 src/lib/elm_interface_scrollable.eo | 2 +-
 src/lib/elm_map.eo  | 2 +-
 3 files changed, 3 insertions(+), 3 deletions(-)

diff --git a/src/lib/elm_gengrid.eo b/src/lib/elm_gengrid.eo
index d808ef6..e4f1e8e 100644
--- a/src/lib/elm_gengrid.eo
+++ b/src/lib/elm_gengrid.eo
@@ -437,7 +437,7 @@ class Elm_Gengrid (Elm_Layout, Elm_Interface_Scrollable,
 
 Mouse wheel can be used for the user to scroll up and down the 
gengrid.
 
-It's enabled by default.
+Wheel is enabled by default.
 
 @see elm_gengrid_wheel_disabled_get()
 
diff --git a/src/lib/elm_interface_scrollable.eo 
b/src/lib/elm_interface_scrollable.eo
index f239fc3..028b8a7 100644
--- a/src/lib/elm_interface_scrollable.eo
+++ b/src/lib/elm_interface_scrollable.eo
@@ -69,7 +69,7 @@ mixin Elm_Interface_Scrollable(Evas.Scrollable_Interface, 
Evas.Object_Smart)
  set {
   /* @brief Set Wheel disable
* Enable or disable mouse wheel to be used to scroll the 
scroller content.
-   * It's disabled by default.
+   * Wheel is enabled by default.
*
* @ingroup Widget
*/
diff --git a/src/lib/elm_map.eo b/src/lib/elm_map.eo
index 2af68ff..3270097 100644
--- a/src/lib/elm_map.eo
+++ b/src/lib/elm_map.eo
@@ -85,7 +85,7 @@ class Elm_Map (Elm_Widget, Elm_Interface_Scrollable,
 
 Mouse wheel can be used for the user to zoom in or zoom out the 
map.
 
-It's disabled by default.
+Wheel is enabled by default.
 
 @see elm_map_wheel_disabled_get()
 

-- 




[EGIT] [core/elementary] master 01/01: multibuttonentry: This fixes item, clicked cb broken issue.

2015-04-20 Thread Amitesh Singh
hermet pushed a commit to branch master.

http://git.enlightenment.org/core/elementary.git/commit/?id=c3d88e790cd0566902853f2afbf415de4b1fe58c

commit c3d88e790cd0566902853f2afbf415de4b1fe58c
Author: Amitesh Singh amitesh...@samsung.com
Date:   Tue Apr 21 11:58:32 2015 +0900

multibuttonentry: This fixes item,clicked cb broken issue.

Summary: This fixes T2334.

Test Plan: elementary_test - multibuttonentry

Reviewers: raster, Hermet

Reviewed By: Hermet

Subscribers: DaveMDS, seoz, sachin.dev

Maniphest Tasks: T2334

Differential Revision: https://phab.enlightenment.org/D2379
---
 src/lib/elc_multibuttonentry.c | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/src/lib/elc_multibuttonentry.c b/src/lib/elc_multibuttonentry.c
index 7e4ec4b..797008a 100644
--- a/src/lib/elc_multibuttonentry.c
+++ b/src/lib/elc_multibuttonentry.c
@@ -486,7 +486,7 @@ _on_item_clicked(void *data,
_item_select(WIDGET(it), it);
 
if (sd-selected_it)
- evas_object_smart_callback_call(VIEW(it), SIG_ITEM_CLICKED, eo_it);
+ evas_object_smart_callback_call(WIDGET(it), SIG_ITEM_CLICKED, eo_it);
 }
 
 static void

-- 




[EGIT] [core/enlightenment] enlightenment-0.19 01/02: add function for clearing app menu cache

2015-04-20 Thread Mike Blumenkrantz
discomfitor pushed a commit to branch enlightenment-0.19.

http://git.enlightenment.org/core/enlightenment.git/commit/?id=a312cc24291634a16fe532c34c87d20d87d28ee5

commit a312cc24291634a16fe532c34c87d20d87d28ee5
Author: Mike Blumenkrantz zm...@osg.samsung.com
Date:   Mon Apr 20 16:04:31 2015 -0400

add function for clearing app menu cache

ref T2271
---
 src/bin/e_int_menus.c | 7 +++
 src/bin/e_int_menus.h | 2 +-
 2 files changed, 8 insertions(+), 1 deletion(-)

diff --git a/src/bin/e_int_menus.c b/src/bin/e_int_menus.c
index 0ba2ae9..97c1f58 100644
--- a/src/bin/e_int_menus.c
+++ b/src/bin/e_int_menus.c
@@ -501,6 +501,13 @@ e_int_menus_menu_augmentation_del(const char *menu, 
E_Int_Menu_Augmentation *mau
 }
 
 EAPI void
+e_int_menus_cache_clear(void)
+{
+   if (_e_int_menus_app_menus)
+ eina_hash_free_buckets(_e_int_menus_app_menus);
+}
+
+EAPI void
 e_int_menus_menu_augmentation_point_disabled_set(const char *menu, Eina_Bool 
disabled)
 {
if (!menu) return;
diff --git a/src/bin/e_int_menus.h b/src/bin/e_int_menus.h
index 757678c..8af6532 100644
--- a/src/bin/e_int_menus.h
+++ b/src/bin/e_int_menus.h
@@ -84,7 +84,7 @@ EAPI void 
e_int_menus_menu_augmentation_del(const char *menu
 
 EAPI void 
e_int_menus_menu_augmentation_point_disabled_set(const char *menu,
Eina_Bool disabled);
-
+EAPI void e_int_menus_cache_clear(void);
 EINTERN void e_int_menus_init(void);
 EINTERN void e_int_menus_shutdown(void);
 #endif

-- 




[EGIT] [admin/release-management] master 01/01: Make sure the formatting is generated the way we need it in NEWS

2015-04-20 Thread Stefan Schmidt
stefan pushed a commit to branch master.

http://git.enlightenment.org/admin/release-management.git/commit/?id=30904f27f33c0957ef18aa2ebb40863d34922682

commit 30904f27f33c0957ef18aa2ebb40863d34922682
Author: Stefan Schmidt s.schm...@samsung.com
Date:   Mon Apr 20 13:36:49 2015 +0200

Make sure the formatting is generated the way we need it in NEWS

Long standing change I needed to do. I always fixed these up manually.
No big thing but got annoying.
---
 generate_news.py | 2 +-
 release.sh   | 2 +-
 2 files changed, 2 insertions(+), 2 deletions(-)

diff --git a/generate_news.py b/generate_news.py
index c55aa5a..1b60b3c 100755
--- a/generate_news.py
+++ b/generate_news.py
@@ -50,7 +50,7 @@ def news_features_print(commit_range):
 news_range_print(commit_range, 'feature')
 
 def news_fixes_print(commit_range):
-print('Fixes:\n')
+print('\nFixes:\n')
 news_range_print(commit_range, 'fix')
 
 def run(args):
diff --git a/release.sh b/release.sh
index 60c64ec..586983f 100755
--- a/release.sh
+++ b/release.sh
@@ -36,7 +36,7 @@ do_package_and_upload()
make clean distclean || exit 1
$EDITOR configure.ac || exit 1
echo Changes since $OLD_VERSION:  NEWS
-   echo -  NEWS
+   echo -e -\n  NEWS
../release-management/generate_news.py v$OLD_VERSION..HEAD  NEWS || 
exit 1
git diff
$EDITOR NEWS || exit 1

-- 




[EGIT] [core/emotion_generic_players] master 01/01: release: Update NEWS and bump version for 1.14.0-beta2 release

2015-04-20 Thread Stefan Schmidt
stefan pushed a commit to branch master.

http://git.enlightenment.org/core/emotion_generic_players.git/commit/?id=51ec7abd0beaa3de17ff0604952d2c31fe8cd5b1

commit 51ec7abd0beaa3de17ff0604952d2c31fe8cd5b1
Author: Stefan Schmidt s.schm...@samsung.com
Date:   Mon Apr 20 12:37:25 2015 +0200

release: Update NEWS and bump version for 1.14.0-beta2 release
---
 configure.ac | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/configure.ac b/configure.ac
index fe83562..008e709 100644
--- a/configure.ac
+++ b/configure.ac
@@ -18,7 +18,7 @@ m4_define([lt_age], v_min)
 ##--##--##--##--##--##--##--##--##--##--##--##--##--##--##--##--##
 ##--##--##--##--##--##--##--##--##--##--##--##--##--##--##--##--##
 
-AC_INIT([emotion_generic_players], [v_ver-beta1], 
[enlightenment-de...@lists.sourceforge.net])
+AC_INIT([emotion_generic_players], [v_ver-beta2], 
[enlightenment-de...@lists.sourceforge.net])
 AC_PREREQ([2.59])
 AC_CONFIG_SRCDIR([configure.ac])
 AC_CONFIG_MACRO_DIR([m4])

-- 




[EGIT] [core/efl] master 01/06: Evas GL_X11: Fix memory leak

2015-04-20 Thread Jean-Philippe ANDRÉ
jpeg pushed a commit to branch master.

http://git.enlightenment.org/core/efl.git/commit/?id=6e587b5479665af1107d6c8cd565b3a8d30de2ec

commit 6e587b5479665af1107d6c8cd565b3a8d30de2ec
Author: Jean-Philippe Andre jp.an...@samsung.com
Date:   Mon Apr 20 11:44:27 2015 +0900

Evas GL_X11: Fix memory leak
---
 src/modules/evas/engines/gl_x11/evas_x_main.c | 2 ++
 1 file changed, 2 insertions(+)

diff --git a/src/modules/evas/engines/gl_x11/evas_x_main.c 
b/src/modules/evas/engines/gl_x11/evas_x_main.c
index 71f54e0..4b1ebab 100644
--- a/src/modules/evas/engines/gl_x11/evas_x_main.c
+++ b/src/modules/evas/engines/gl_x11/evas_x_main.c
@@ -1109,6 +1109,7 @@ try_again:
  {
 ERR(glXChooseFBConfig() can't find any configs (alpha: %d, depth: %d, 
stencil: %d, msaa: %d),
 alpha, depth_bits, stencil_bits, msaa_samples);
+if (configs) XFree(configs);
 if ((depth_bits  24) || (stencil_bits  8))
   {
  WRN(Please note that your driver might not support 32-bit depth 
or 
@@ -1187,6 +1188,7 @@ try_again:
 XFree(visinfo);
  }
 
+   XFree(configs);
if (!found)
  {
 ERR(Could not find a matching config. Now what?);

-- 




[EGIT] [core/efl] master 03/06: Eina tests: fix warning about pointer signedness

2015-04-20 Thread Jean-Philippe ANDRÉ
jpeg pushed a commit to branch master.

http://git.enlightenment.org/core/efl.git/commit/?id=7dbb61b0a1977ff216b0af6e66f8afb60dbc518b

commit 7dbb61b0a1977ff216b0af6e66f8afb60dbc518b
Author: Jean-Philippe Andre jp.an...@samsung.com
Date:   Mon Apr 20 15:15:10 2015 +0900

Eina tests: fix warning about pointer signedness
---
 src/tests/eina/eina_test_str.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/src/tests/eina/eina_test_str.c b/src/tests/eina/eina_test_str.c
index c70c7e7..be879db 100644
--- a/src/tests/eina/eina_test_str.c
+++ b/src/tests/eina/eina_test_str.c
@@ -317,7 +317,7 @@ START_TEST(str_memdup)
   double d;
} t1,*t2;
unsigned char buf[7];
-   char *temp_buf;
+   unsigned char *temp_buf;
 
eina_init();
 
@@ -333,7 +333,7 @@ START_TEST(str_memdup)
 
memcpy(buf, aaabbb, 6);
temp_buf = eina_memdup(buf, 6, EINA_TRUE);
-   fail_if(strcmp(temp_buf, aaabbb) != 0);
+   fail_if(strcmp((char *) temp_buf, aaabbb) != 0);
free(temp_buf);
 
eina_shutdown();

-- 




[EGIT] [core/efl] master 05/06: Evas: Remove callbacks in reverse order with callback_del

2015-04-20 Thread Jean-Philippe ANDRÉ
jpeg pushed a commit to branch master.

http://git.enlightenment.org/core/efl.git/commit/?id=1dddbbd8f76a966328a205b170a38604724b

commit 1dddbbd8f76a966328a205b170a38604724b
Author: Jean-Philippe Andre jp.an...@samsung.com
Date:   Mon Apr 20 16:31:36 2015 +0900

Evas: Remove callbacks in reverse order with callback_del

This function is deprecated, because del_full should be used instead.
Still, the documentation specifies in which order the callbacks should
be deleted.

Fixes T2077 (not really fixes according to the comment but fixes
according to the doc).
---
 src/lib/evas/canvas/evas_callbacks.c | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/src/lib/evas/canvas/evas_callbacks.c 
b/src/lib/evas/canvas/evas_callbacks.c
index 52bd014..e7526ba 100644
--- a/src/lib/evas/canvas/evas_callbacks.c
+++ b/src/lib/evas/canvas/evas_callbacks.c
@@ -328,7 +328,7 @@ evas_object_event_callback_del(Evas_Object *eo_obj, 
Evas_Callback_Type type, Eva
 
if (!obj-callbacks) return NULL;
 
-   EINA_INLIST_FOREACH(obj-callbacks, info)
+   EINA_INLIST_REVERSE_FOREACH(obj-callbacks, info)
  {
 if ((info-func == func)  (info-type == type))
   {

-- 




[EGIT] [core/efl] master 01/01: Evas: Fix memory leak

2015-04-20 Thread Jean-Philippe ANDRÉ
jpeg pushed a commit to branch master.

http://git.enlightenment.org/core/efl.git/commit/?id=1804d460eeeb7cda9ec3ee82ebbd2ca6cfbf44cc

commit 1804d460eeeb7cda9ec3ee82ebbd2ca6cfbf44cc
Author: Jean-Philippe Andre jp.an...@samsung.com
Date:   Mon Apr 20 17:34:15 2015 +0900

Evas: Fix memory leak

Fixes CID 1293000
---
 src/modules/evas/engines/gl_generic/evas_engine.c | 5 -
 1 file changed, 4 insertions(+), 1 deletion(-)

diff --git a/src/modules/evas/engines/gl_generic/evas_engine.c 
b/src/modules/evas/engines/gl_generic/evas_engine.c
index b926d2b..93521bd 100644
--- a/src/modules/evas/engines/gl_generic/evas_engine.c
+++ b/src/modules/evas/engines/gl_generic/evas_engine.c
@@ -2207,7 +2207,10 @@ eng_ector_renderer_draw(void *data, void *context 
EINA_UNUSED, void *surface, Ec
 
 if (eina_array_count(c) == 0 
 eina_array_count(clips)  0)
-  return ;
+  {
+ eina_array_free(c);
+ return;
+  }
  }
 
if (eina_array_count(c) == 0)

-- 




[EGIT] [core/elementary] master 01/01: Elm win: Add a warning to wl_id_get func.

2015-04-20 Thread Tom Hacohen
tasn pushed a commit to branch master.

http://git.enlightenment.org/core/elementary.git/commit/?id=24323d649a946c11493dc9537317f780e4da0dfd

commit 24323d649a946c11493dc9537317f780e4da0dfd
Author: Tom Hacohen t...@stosb.com
Date:   Mon Apr 20 10:18:42 2015 +0100

Elm win: Add a warning to wl_id_get func.

As discussed on IRC, users of this API should be warned, as it's
almost always a bad idea.
---
 src/lib/elm_win_legacy.h | 3 +++
 1 file changed, 3 insertions(+)

diff --git a/src/lib/elm_win_legacy.h b/src/lib/elm_win_legacy.h
index 42bd662..42a875f 100644
--- a/src/lib/elm_win_legacy.h
+++ b/src/lib/elm_win_legacy.h
@@ -184,6 +184,9 @@ EAPI void  elm_win_render(Evas_Object *obj);
 /**
  * Get the Ecore_Wl_Window of an Evas_Object
  *
+ * Do not use this function if you'd like your application/library be portable.
+ * You have been warned.
+ *
  * @param obj the object
  *
  * @return The Ecore_Wl_Window of @p obj

-- 




[EGIT] [core/efl] master 01/01: release: Update NEWS and bump version for 1.14.0-beta2 release

2015-04-20 Thread Stefan Schmidt
stefan pushed a commit to branch master.

http://git.enlightenment.org/core/efl.git/commit/?id=b81b29eba2f30ee2168af90cc546c5f557f5e5f4

commit b81b29eba2f30ee2168af90cc546c5f557f5e5f4
Author: Stefan Schmidt s.schm...@samsung.com
Date:   Mon Apr 20 12:17:35 2015 +0200

release: Update NEWS and bump version for 1.14.0-beta2 release
---
 NEWS | 14 ++
 configure.ac |  2 +-
 2 files changed, 15 insertions(+), 1 deletion(-)

diff --git a/NEWS b/NEWS
index 404c785..9beb336 100644
--- a/NEWS
+++ b/NEWS
@@ -191,6 +191,20 @@ Fixes:
* evas-gl-x11: Fix dereference before null check (CID1293519)
* evas-software-x11: Fix dereference before null check(s) (CID1270030, 
CID1270028, CID1270029)
* Evas object: verify the parent is valid and fail if not.
+   * efreetd: If we fail to allocate space for subdir_cache, then get out 
(CID1294212)
+   * Evas GL: Fallback to indirect rendering if mul_col != 0x
+   * eo_gdb.py: fix syntax error
+   * eio: reorder tests linkage to unbreak debian-based systems
+   * evas-drm: Handle render mode for 4 buffers
+   * ecore-drm: Add pending_flip field to Ecore_Drm_Fb
+   * evas-drm: Mark the Ecore_Drm_Fb as complete when we get the page flip 
event. (T2289)
+   * ecore-drm: Fix hotplugging of outputs
+   * ecore-drm: Fix mouse movement across multiple outputs
+   * ecore-drm: Don't fetch output geometry on every mouse movement
+   * evas: fix possible segfault in evas_3d_node_member_add/del.
+   * Evas textblock: remove freed item from the line list
+   * evas: restore the value of do_region in jpeg loader as EINA_TRUE
+   * emotion - gst1 module - handle long standing bad map/unmap of gst buf
 
 Changes since 1.12.0:
 -
diff --git a/configure.ac b/configure.ac
index fbd3b52..a0dc51e 100644
--- a/configure.ac
+++ b/configure.ac
@@ -1,5 +1,5 @@
 EFL_VERSION([1], [14], [0], [release])
-AC_INIT([efl], [efl_version-beta1], 
[enlightenment-de...@lists.sourceforge.net])
+AC_INIT([efl], [efl_version-beta2], 
[enlightenment-de...@lists.sourceforge.net])
 
 AC_PREREQ([2.60])
 AC_CONFIG_SRCDIR([configure.ac])

-- 




[EGIT] [core/efl] master 02/06: Eina tests: suppress warnings over deprecated functions

2015-04-20 Thread Jean-Philippe ANDRÉ
jpeg pushed a commit to branch master.

http://git.enlightenment.org/core/efl.git/commit/?id=c2a9dd3a318f467754c8da208d9fbc928dc8f6e1

commit c2a9dd3a318f467754c8da208d9fbc928dc8f6e1
Author: Jean-Philippe Andre jp.an...@samsung.com
Date:   Mon Apr 20 15:14:47 2015 +0900

Eina tests: suppress warnings over deprecated functions
---
 src/tests/eina/eina_test_binbuf.c | 5 +
 1 file changed, 5 insertions(+)

diff --git a/src/tests/eina/eina_test_binbuf.c 
b/src/tests/eina/eina_test_binbuf.c
index 14a2526..1b0de28 100644
--- a/src/tests/eina/eina_test_binbuf.c
+++ b/src/tests/eina/eina_test_binbuf.c
@@ -98,6 +98,10 @@ START_TEST(binbuf_remove)
 }
 END_TEST
 
+/* eina_binbuf_manage_new_length and eina_binbuf_manage_read_only_new_length
+ * are deprecated */
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored -Wdeprecated-declarations
 START_TEST(binbuf_manage_simple)
 {
Eina_Binbuf *buf;
@@ -154,6 +158,7 @@ START_TEST(binbuf_manage_read_only_simple)
eina_shutdown();
 }
 END_TEST
+#pragma GCC diagnostic pop
 
 START_TEST(binbuf_insert)
 {

-- 




[EGIT] [core/efl] master 02/02: emotion gst1 module - remove printf

2015-04-20 Thread Carsten Haitzler
raster pushed a commit to branch master.

http://git.enlightenment.org/core/efl.git/commit/?id=425de99145ff40aaea58d8df2ed0f36ade6443bc

commit 425de99145ff40aaea58d8df2ed0f36ade6443bc
Author: Carsten Haitzler (Rasterman) ras...@rasterman.com
Date:   Mon Apr 20 12:14:10 2015 +0900

emotion gst1 module - remove printf

this debugging printf seems to have been left around - remove it so we
don't get unexpected noise in gst playback
---
 src/modules/emotion/gstreamer1/emotion_sink.c | 3 ---
 1 file changed, 3 deletions(-)

diff --git a/src/modules/emotion/gstreamer1/emotion_sink.c 
b/src/modules/emotion/gstreamer1/emotion_sink.c
index 6c410f8..eda2a6a 100644
--- a/src/modules/emotion/gstreamer1/emotion_sink.c
+++ b/src/modules/emotion/gstreamer1/emotion_sink.c
@@ -348,9 +348,6 @@ _update_emotion_fps(EmotionVideoSinkPrivate *priv)
  }
else if ((tim - priv-rlapse) = 0.5)
  {
-printf(FRAME: %i, FPS: %3.1f\n,
-   priv-frames,
-   (priv-frames - priv-flapse) / (tim - priv-rlapse));
 priv-rlapse = tim;
 priv-flapse = priv-frames;
  }

-- 




[EGIT] [core/efl] master 01/02: emotion - gst1 module - handle long standing bad map/unmap of gst buf

2015-04-20 Thread Carsten Haitzler
raster pushed a commit to branch master.

http://git.enlightenment.org/core/efl.git/commit/?id=6458ca32bc80062e95337c5ebb36593723567a37

commit 6458ca32bc80062e95337c5ebb36593723567a37
Author: Carsten Haitzler (Rasterman) ras...@rasterman.com
Date:   Mon Apr 20 12:12:27 2015 +0900

emotion - gst1 module - handle long standing bad map/unmap of gst buf

this fixes a pending XXX where we didnt keep the buffer mapped as long
as the evas image object pointed to the video pixel data. this fixes
this along with less over-zealous refinf to make things more obvious
(now last_buffer actualyl really matters and if it was mapped and
refed).

@fix
---
 src/modules/emotion/gstreamer1/emotion_gstreamer.h |  2 +
 src/modules/emotion/gstreamer1/emotion_sink.c  | 46 +-
 2 files changed, 39 insertions(+), 9 deletions(-)

diff --git a/src/modules/emotion/gstreamer1/emotion_gstreamer.h 
b/src/modules/emotion/gstreamer1/emotion_gstreamer.h
index 080ab77..dfee8e4 100644
--- a/src/modules/emotion/gstreamer1/emotion_gstreamer.h
+++ b/src/modules/emotion/gstreamer1/emotion_gstreamer.h
@@ -109,6 +109,7 @@ struct _EmotionVideoSinkPrivate {
 
 /* We need to keep a copy of the last inserted buffer as evas doesn't copy 
YUV data around */
GstBuffer*last_buffer;
+   GstMapInfomap_info;
 
int frames;
int flapse;
@@ -124,6 +125,7 @@ struct _EmotionVideoSinkPrivate {
//
// Protected by the buffer mutex
Eina_Bool unlocked : 1;
+   Eina_Bool mapped : 1;
 };
 
 struct _Emotion_Gstreamer_Buffer
diff --git a/src/modules/emotion/gstreamer1/emotion_sink.c 
b/src/modules/emotion/gstreamer1/emotion_sink.c
index 5e6f3be..6c410f8 100644
--- a/src/modules/emotion/gstreamer1/emotion_sink.c
+++ b/src/modules/emotion/gstreamer1/emotion_sink.c
@@ -137,6 +137,22 @@ emotion_video_sink_dispose(GObject* object)
sink = EMOTION_VIDEO_SINK(object);
priv = sink-priv;
 
+   if ((priv-mapped)  (priv-last_buffer))
+ {
+if (priv-evas_object)
+  {
+ evas_object_image_size_set(priv-evas_object, 1, 1);
+ evas_object_image_data_set(priv-evas_object, NULL);
+  }
+gst_buffer_unmap(priv-last_buffer, (priv-map_info));
+priv-mapped = EINA_FALSE;
+ }
+   if (priv-last_buffer)
+ {
+if (priv-last_buffer) gst_buffer_unref(priv-last_buffer);
+priv-last_buffer = NULL;
+ }
+
eina_lock_free(priv-m);
eina_condition_free(priv-c);
 
@@ -210,9 +226,21 @@ emotion_video_sink_stop(GstBaseSink* base_sink)
 
INF(sink stop);
 
-   gst_buffer_replace(priv-last_buffer, NULL);
-
eina_lock_take(priv-m);
+   if (priv-last_buffer)
+ {
+if (priv-evas_object)
+  {
+ evas_object_image_size_set(priv-evas_object, 1, 1);
+ evas_object_image_data_set(priv-evas_object, NULL);
+  }
+if (priv-mapped)
+  gst_buffer_unmap(priv-last_buffer, (priv-map_info));
+priv-mapped = EINA_FALSE;
+if (priv-last_buffer) gst_buffer_unref(priv-last_buffer);
+priv-last_buffer = NULL;
+ }
+
/* If there still is a pending frame, neutralize it */
if (priv-send)
  {
@@ -371,8 +399,6 @@ emotion_video_sink_main_render(void *data)
 
buffer = gst_buffer_ref(send-frame);
 
-   // XXX: need to map buffer and KEEP MAPPED until we set new video data or
-   // on the evas image object or release the object
if (!gst_buffer_map(buffer, map, GST_MAP_READ))
  goto exit_point;
 
@@ -391,9 +417,6 @@ emotion_video_sink_main_render(void *data)
else
  WRN(No way to decode %x colorspace !, send-eformat);
 
-   // XXX: this unmap here is broken
-   gst_buffer_unmap(buffer, map);
-
evas_object_image_data_set(priv-evas_object, evas_data);
evas_object_image_data_update_add(priv-evas_object, 0, 0, 
send-info.width, send-eheight);
evas_object_image_pixels_dirty_set(priv-evas_object, 0);
@@ -405,7 +428,13 @@ emotion_video_sink_main_render(void *data)
 
_emotion_frame_resize(priv-emotion_object, send-info.width, 
send-eheight, ratio);
 
-   gst_buffer_replace(priv-last_buffer, buffer);
+   if ((priv-mapped)  (priv-last_buffer))
+ gst_buffer_unmap(priv-last_buffer, (priv-map_info));
+   priv-map_info = map;
+   priv-mapped = EINA_TRUE;
+
+   if (priv-last_buffer) gst_buffer_unref(priv-last_buffer);
+   priv-last_buffer = buffer;
 
_emotion_frame_new(priv-emotion_object);
 
@@ -415,7 +444,6 @@ emotion_video_sink_main_render(void *data)
 
eina_lock_release(priv-m);
 
-   if (buffer) gst_buffer_unref(buffer);
emotion_gstreamer_buffer_free(send);
 
_emotion_pending_ecore_end();

-- 




[EGIT] [core/evas_generic_loaders] master 01/01: release: Update NEWS and bump version for 1.14.0-beta2 release

2015-04-20 Thread Stefan Schmidt
stefan pushed a commit to branch master.

http://git.enlightenment.org/core/evas_generic_loaders.git/commit/?id=e985059f065cab57b0d20eb46dfa93f2f9548434

commit e985059f065cab57b0d20eb46dfa93f2f9548434
Author: Stefan Schmidt s.schm...@samsung.com
Date:   Mon Apr 20 12:36:41 2015 +0200

release: Update NEWS and bump version for 1.14.0-beta2 release
---
 configure.ac | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/configure.ac b/configure.ac
index d56d6a1..5d6fc1c 100644
--- a/configure.ac
+++ b/configure.ac
@@ -17,7 +17,7 @@ m4_define([lt_age], v_min)
 ##--##--##--##--##--##--##--##--##--##--##--##--##--##--##--##--##
 ##--##--##--##--##--##--##--##--##--##--##--##--##--##--##--##--##
 
-AC_INIT([evas_generic_loaders], [v_ver-beta1], 
[enlightenment-de...@lists.sourceforge.net])
+AC_INIT([evas_generic_loaders], [v_ver-beta2], 
[enlightenment-de...@lists.sourceforge.net])
 AC_PREREQ([2.52])
 AC_CONFIG_SRCDIR([configure.ac])
 AC_CONFIG_MACRO_DIR([m4])

-- 




[EGIT] [core/elementary] master 01/01: release: Update NEWS and bump version for 1.14.0-beta2 release

2015-04-20 Thread Stefan Schmidt
stefan pushed a commit to branch master.

http://git.enlightenment.org/core/elementary.git/commit/?id=060613ac29696a9fd55b84815ed5abdc91c255b1

commit 060613ac29696a9fd55b84815ed5abdc91c255b1
Author: Stefan Schmidt s.schm...@samsung.com
Date:   Mon Apr 20 12:38:33 2015 +0200

release: Update NEWS and bump version for 1.14.0-beta2 release
---
 NEWS | 6 ++
 configure.ac | 2 +-
 2 files changed, 7 insertions(+), 1 deletion(-)

diff --git a/NEWS b/NEWS
index b81db99..ab91a44 100644
--- a/NEWS
+++ b/NEWS
@@ -72,6 +72,12 @@ Fixes:
* [elm_panel] Fix mirroring issue.
* test_naviframe: Fix content image file names.
* elm_image: return EINA_FALSE if the data source is NULL in 
elm_image_memfile_set
+   * spinner: fix entry style in non 'button_layout' mode
+   * elm_gengrid: mark cursor_engine_only in data and update state when 
realized
+   * atspi: add missing signals array sentiel.
+   * elementary: Fix elm_win_window_id_get for wayland
+   * elm_slider: fix theme apply
+   * elm_clock: fix theme apply
 
 Changes since 1.12.0:
 -
diff --git a/configure.ac b/configure.ac
index c492469..95737e8 100644
--- a/configure.ac
+++ b/configure.ac
@@ -1,5 +1,5 @@
 EFL_VERSION([1], [14], [0], [release])
-AC_INIT([elementary], [efl_version-beta1], 
[enlightenment-de...@lists.sourceforge.net])
+AC_INIT([elementary], [efl_version-beta2], 
[enlightenment-de...@lists.sourceforge.net])
 
 AC_PREREQ(2.63)
 AC_CONFIG_SRCDIR([configure.ac])

-- 




[EGIT] [core/efl] master 01/01: bindings/eo: Only install Eo.hh once to avoid failing double install

2015-04-20 Thread Stefan Schmidt
stefan pushed a commit to branch master.

http://git.enlightenment.org/core/efl.git/commit/?id=c65028228559d9e4da4984835026d0c3c098daa3

commit c65028228559d9e4da4984835026d0c3c098daa3
Author: Stefan Schmidt s.schm...@samsung.com
Date:   Mon Apr 20 09:12:34 2015 +0200

bindings/eo: Only install Eo.hh once to avoid failing double install

Eo.hh is listed in both dist_installed_eocxxmainheaders_DATA and
dist_installed_eocxxheaders_DATA this leads to a situation where they file
should be installed but already exists and thus the installation fails.

00:32:27.919 /usr/bin/install: cannot create regular file 
'/srv/build/workspace/changely_efl_configure_xcb/destdir/include/eo-cxx-1/Eo.hh':
 File exists
00:32:27.923 Makefile:32620: recipe for target 
'install-dist_installed_eocxxmainheadersDATA' failed
00:32:27.923 make[4]: *** [install-dist_installed_eocxxmainheadersDATA] 
Error

Given that it is the only item in dist_installed_eocxxmainheaders_DATA I 
suspect
it was but into the other rule by accident.
---
 src/Makefile_Eo_Cxx.am | 1 -
 1 file changed, 1 deletion(-)

diff --git a/src/Makefile_Eo_Cxx.am b/src/Makefile_Eo_Cxx.am
index b6315c8..a3c898d 100644
--- a/src/Makefile_Eo_Cxx.am
+++ b/src/Makefile_Eo_Cxx.am
@@ -29,7 +29,6 @@ bindings/eo_cxx/eo_inherit.hh \
 bindings/eo_cxx/eo_ops.hh \
 bindings/eo_cxx/eo_private.hh \
 bindings/eo_cxx/eo_inherit_bindings.hh \
-bindings/eo_cxx/Eo.hh \
 bindings/eo_cxx/eo_cxx_interop.hh
 
 endif

-- 




[EGIT] [core/elementary] annotated tag v1.14.0-beta2 created (now 1d04e91)

2015-04-20 Thread Enlightenment Git
This is an automated email from the git hooks/post-receive script.

stefan pushed a change to annotated tag v1.14.0-beta2
in repository core/elementary.

at  1d04e91   (tag)
   tagging  060613ac29696a9fd55b84815ed5abdc91c255b1 (commit)
  replaces  v1.14.0-beta1
 tagged by  Stefan Schmidt
on  Mon Apr 20 12:52:16 2015 +0200

- Log -
v1.14.0-beta2

Andrii Kroitor (3):
  spinner: fix entry style in non 'button_layout' mode
  elm_slider: fix theme apply
  elm_clock: fix theme apply

Carsten Haitzler (1):
  elm - fix repeat event fix - thanks dave

Christopher Michael (2):
  elementary: Fix elm_win_window_id_get for wayland
  Revert elementary: Fix elm_win_window_id_get for wayland

ChunEon Park (4):
  radio: update doc
  multibuttonentry: changed longpress callback name.
  multibuttonentry: update longpress signal case.
  Revert checkbox: Adding third state (Indeterminate) support in checkbox

Daniel Kolesa (1):
  mailmap: update q66

Dave Andreoli (1):
  Add missing file_get legacy definition for Video and Layout

Jaeun Choi (1):
  elm_gengrid: mark cursor_engine_only in data and update state when 
realized

Jean-Philippe ANDRÉ (1):
  elm_glview: make_current(NULL, NULL) before delete

Lukasz Stanislawski (1):
  atspi: add missing signals array sentiel.

Mike Blumenkrantz (5):
  colorclass: flush config after saving
  colorclass: add reset signal for correctly managing remote colorclass 
resets
  colorclass: only perform remote actions if current editor is remote
  toolbar: fix conditional compiler warning in horizontal_set
  win: add note for (mis)users of elm_win_window_id_get()

Shobhit (1):
  checkbox: Adding third state (Indeterminate) support in checkbox

Stefan Schmidt (3):
  build: Make sure we remove check-results.xml during cleanup
  elm_color_class: Avoid resource leak
  release: Update NEWS and bump version for 1.14.0-beta2 release

Tom Hacohen (1):
  Elm win: Add a warning to wl_id_get func.

---

No new revisions were added by this update.

-- 




[EGIT] [core/evas_generic_loaders] annotated tag v1.14.0-beta2 created (now 6f22c91)

2015-04-20 Thread Enlightenment Git
This is an automated email from the git hooks/post-receive script.

stefan pushed a change to annotated tag v1.14.0-beta2
in repository core/evas_generic_loaders.

at  6f22c91   (tag)
   tagging  e985059f065cab57b0d20eb46dfa93f2f9548434 (commit)
  replaces  v1.14.0-beta1
 tagged by  Stefan Schmidt
on  Mon Apr 20 12:52:07 2015 +0200

- Log -
v1.14.0-beta2

Stefan Schmidt (1):
  release: Update NEWS and bump version for 1.14.0-beta2 release

---

No new revisions were added by this update.

-- 




[EGIT] [core/efl] master 01/02: Ector: remove use of #warning directive as TODO.

2015-04-20 Thread Tom Hacohen
tasn pushed a commit to branch master.

http://git.enlightenment.org/core/efl.git/commit/?id=1807adf70ba8e2a8e6ae0a8e0e92930ca8105b5d

commit 1807adf70ba8e2a8e6ae0a8e0e92930ca8105b5d
Author: Tom Hacohen t...@stosb.com
Date:   Mon Apr 20 15:00:13 2015 +0100

Ector: remove use of #warning directive as TODO.

There's already a fixme in code, and an error output at runtime.
As discussed on the ML, using #warning this way is bad.
---
 src/lib/ector/cairo/ector_renderer_cairo_shape.c | 1 -
 1 file changed, 1 deletion(-)

diff --git a/src/lib/ector/cairo/ector_renderer_cairo_shape.c 
b/src/lib/ector/cairo/ector_renderer_cairo_shape.c
index de6aa6d..ceab6c4 100644
--- a/src/lib/ector/cairo/ector_renderer_cairo_shape.c
+++ b/src/lib/ector/cairo/ector_renderer_cairo_shape.c
@@ -225,7 +225,6 @@ 
_ector_renderer_cairo_shape_ector_renderer_cairo_base_fill(Eo *obj EINA_UNUSED,
 {
// FIXME: let's find out how to fill a shape with a shape later.
// I need to read SVG specification and see how to map that with cairo.
-#warning fill for a shape object is unhandled at this moment in cairo 
backend.
ERR(fill with shape not implemented\n);
return EINA_FALSE;
 }

-- 




[EGIT] [core/enlightenment] master 01/01: Make some randr messages translatable

2015-04-20 Thread Massimo Maiurana
maxerba pushed a commit to branch master.

http://git.enlightenment.org/core/enlightenment.git/commit/?id=6604268f2d9b25447b7426017388a630c11a702f

commit 6604268f2d9b25447b7426017388a630c11a702f
Author: maxerba maiur...@gmail.com
Date:   Mon Apr 20 16:23:33 2015 +0200

Make some randr messages translatable
---
 po/POTFILES.in   |  1 +
 src/modules/conf_randr/e_int_config_randr2.c | 58 ++--
 2 files changed, 30 insertions(+), 29 deletions(-)

diff --git a/po/POTFILES.in b/po/POTFILES.in
index c59c782..f692a09 100644
--- a/po/POTFILES.in
+++ b/po/POTFILES.in
@@ -172,6 +172,7 @@ src/modules/conf_paths/e_mod_main.c
 src/modules/conf_performance/e_int_config_performance.c
 src/modules/conf_performance/e_int_config_powermanagement.c
 src/modules/conf_performance/e_mod_main.c
+src/modules/conf_randr/e_int_config_randr.c
 src/modules/conf_randr/e_int_config_randr2.c
 src/modules/conf_randr/e_mod_main.c
 src/modules/conf_shelves/e_int_config_shelf.c
diff --git a/src/modules/conf_randr/e_int_config_randr2.c 
b/src/modules/conf_randr/e_int_config_randr2.c
index 78a99d4..57c3bf4 100644
--- a/src/modules/conf_randr/e_int_config_randr2.c
+++ b/src/modules/conf_randr/e_int_config_randr2.c
@@ -310,17 +310,17 @@ _basic_screen_info_fill(E_Config_Dialog_Data *cfdata, 
E_Config_Randr2_Screen *cs
elm_slider_value_set(cfdata-priority_obj, cs-priority);
 
if (cs-rel_mode == E_RANDR2_RELATIVE_NONE)
- elm_object_text_set(cfdata-rel_mode_obj, None);
+ elm_object_text_set(cfdata-rel_mode_obj, _(None));
else if (cs-rel_mode == E_RANDR2_RELATIVE_CLONE)
- elm_object_text_set(cfdata-rel_mode_obj, Clone);
+ elm_object_text_set(cfdata-rel_mode_obj, _(Clone));
else if (cs-rel_mode == E_RANDR2_RELATIVE_TO_LEFT)
- elm_object_text_set(cfdata-rel_mode_obj, Left of);
+ elm_object_text_set(cfdata-rel_mode_obj, _(Left of));
else if (cs-rel_mode == E_RANDR2_RELATIVE_TO_RIGHT)
- elm_object_text_set(cfdata-rel_mode_obj, Right of);
+ elm_object_text_set(cfdata-rel_mode_obj, _(Right of));
else if (cs-rel_mode == E_RANDR2_RELATIVE_TO_ABOVE)
- elm_object_text_set(cfdata-rel_mode_obj, Above);
+ elm_object_text_set(cfdata-rel_mode_obj, _(Above));
else if (cs-rel_mode == E_RANDR2_RELATIVE_TO_BELOW)
- elm_object_text_set(cfdata-rel_mode_obj, Below);
+ elm_object_text_set(cfdata-rel_mode_obj, _(Below));
else
  elm_object_text_set(cfdata-rel_mode_obj, ???);
 
@@ -430,7 +430,7 @@ _cb_rel_mode_none(void *data, Evas_Object *obj, void *event 
EINA_UNUSED)
E_Config_Randr2_Screen *cs = _config_screen_find(cfdata);
if (!cs) return;
cs-rel_mode = E_RANDR2_RELATIVE_NONE;
-   elm_object_text_set(obj, None);
+   elm_object_text_set(obj, _(None));
e_config_dialog_changed_set(cfdata-cfd, EINA_TRUE);
 }
 
@@ -441,7 +441,7 @@ _cb_rel_mode_clone(void *data, Evas_Object *obj, void 
*event EINA_UNUSED)
E_Config_Randr2_Screen *cs = _config_screen_find(cfdata);
if (!cs) return;
cs-rel_mode = E_RANDR2_RELATIVE_CLONE;
-   elm_object_text_set(obj, Clone);
+   elm_object_text_set(obj, _(Clone));
e_config_dialog_changed_set(cfdata-cfd, EINA_TRUE);
 }
 
@@ -452,7 +452,7 @@ _cb_rel_mode_left_of(void *data, Evas_Object *obj, void 
*event EINA_UNUSED)
E_Config_Randr2_Screen *cs = _config_screen_find(cfdata);
if (!cs) return;
cs-rel_mode = E_RANDR2_RELATIVE_TO_LEFT;
-   elm_object_text_set(obj, Left of);
+   elm_object_text_set(obj, _(Left of));
e_config_dialog_changed_set(cfdata-cfd, EINA_TRUE);
 }
 
@@ -463,7 +463,7 @@ _cb_rel_mode_right_of(void *data, Evas_Object *obj, void 
*event EINA_UNUSED)
E_Config_Randr2_Screen *cs = _config_screen_find(cfdata);
if (!cs) return;
cs-rel_mode = E_RANDR2_RELATIVE_TO_RIGHT;
-   elm_object_text_set(obj, Right of);
+   elm_object_text_set(obj, _(Right of));
e_config_dialog_changed_set(cfdata-cfd, EINA_TRUE);
 }
 
@@ -474,7 +474,7 @@ _cb_rel_mode_above(void *data, Evas_Object *obj, void 
*event EINA_UNUSED)
E_Config_Randr2_Screen *cs = _config_screen_find(cfdata);
if (!cs) return;
cs-rel_mode = E_RANDR2_RELATIVE_TO_ABOVE;
-   elm_object_text_set(obj, Above);
+   elm_object_text_set(obj, _(Above));
e_config_dialog_changed_set(cfdata-cfd, EINA_TRUE);
 }
 
@@ -485,7 +485,7 @@ _cb_rel_mode_below(void *data, Evas_Object *obj, void 
*event EINA_UNUSED)
E_Config_Randr2_Screen *cs = _config_screen_find(cfdata);
if (!cs) return;
cs-rel_mode = E_RANDR2_RELATIVE_TO_BELOW;
-   elm_object_text_set(obj, Below);
+   elm_object_text_set(obj, _(Below));
e_config_dialog_changed_set(cfdata-cfd, EINA_TRUE);
 }
 
@@ -537,7 +537,7 @@ _basic_create(E_Config_Dialog *cfd, Evas *evas EINA_UNUSED, 
E_Config_Dialog_Data
o = elm_hoversel_add(win);
evas_object_size_hint_weight_set(o, 0.0, 0.0);
evas_object_size_hint_align_set(o, EVAS_HINT_FILL, 0.5);
-   elm_object_text_set(o, Outputs);
+   elm_object_text_set(o, _(Outputs));

[EGIT] [core/efl] master 01/01: ecore-evas-extn: Use eina_mkstemp in place of mkstemp

2015-04-20 Thread Christopher Michael
devilhorns pushed a commit to branch master.

http://git.enlightenment.org/core/efl.git/commit/?id=ea77578ad65b65933d911987bbc4d21ab28ebb2e

commit ea77578ad65b65933d911987bbc4d21ab28ebb2e
Author: Chris Michael cp.mich...@samsung.com
Date:   Mon Apr 20 12:46:48 2015 -0400

ecore-evas-extn: Use eina_mkstemp in place of mkstemp

Summary: This fixes Coverity CID1039610 'calling mkstemp without
securely setting umask first'. Since we have eina_mkstemp which
already handles creating temporary files in the proper directory,
let's use it.

@fix

Signed-off-by: Chris Michael cp.mich...@samsung.com
---
 src/modules/ecore_evas/engines/extn/ecore_evas_extn_buf.c | 15 +++
 1 file changed, 3 insertions(+), 12 deletions(-)

diff --git a/src/modules/ecore_evas/engines/extn/ecore_evas_extn_buf.c 
b/src/modules/ecore_evas/engines/extn/ecore_evas_extn_buf.c
index 31f83dc..9026615 100644
--- a/src/modules/ecore_evas/engines/extn/ecore_evas_extn_buf.c
+++ b/src/modules/ecore_evas/engines/extn/ecore_evas_extn_buf.c
@@ -19,6 +19,7 @@ _extnbuf_new(const char *base, int id, Eina_Bool sys, int num,
char file[PATH_MAX];
mode_t mode = S_IRUSR | S_IWUSR;
int page_size;
+   Eina_Tmpstr *tmp;
 
page_size = eina_cpu_page_size();
 
@@ -40,18 +41,7 @@ _extnbuf_new(const char *base, int id, Eina_Bool sys, int 
num,

if (b-am_owner)
  {
-const char *s = NULL;
-
-#if defined(HAVE_GETUID)  defined(HAVE_GETEUID)
-if (getuid() == geteuid())
-#endif
-  {
- s = getenv(XDG_RUNTIME_DIR);
- if (!s) s = getenv(TMPDIR);
-  }
-if (!s) s = /tmp;
-snprintf(file, sizeof(file), %s/ee-lock-XX, s);
-b-lockfd = mkstemp(file);
+b-lockfd = eina_file_mkstemp(ee-lock-XX, tmp);
 if (b-lockfd  0) goto err;
 b-lock = eina_stringshare_add(file);
 if (!b-lock) goto err;
@@ -69,6 +59,7 @@ _extnbuf_new(const char *base, int id, Eina_Bool sys, int num,
if (b-addr == MAP_FAILED) goto err;
return b;
 err:
+   if (tmp) eina_tmpstr_del(tmp);
_extnbuf_free(b);
return NULL;
 }

-- 




[EGIT] [core/efl] master 01/01: ecore-evas-x: Fix issue of wrong interface function pointer being set

2015-04-20 Thread Christopher Michael
devilhorns pushed a commit to branch master.

http://git.enlightenment.org/core/efl.git/commit/?id=c66275c99b6ccac9f6ecea04b349c419f7ac390b

commit c66275c99b6ccac9f6ecea04b349c419f7ac390b
Author: Chris Michael cp.mich...@samsung.com
Date:   Mon Apr 20 12:56:46 2015 -0400

ecore-evas-x: Fix issue of wrong interface function pointer being set

Summary: This fixes Coverity CID1267461 where the pointer to the
interface shape_input_reset function was being assigned multiple
times. It looks like this is just a copy/paste error.

@fix

Signed-off-by: Chris Michael cp.mich...@samsung.com
---
 src/modules/ecore_evas/engines/x/ecore_evas_x.c | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/src/modules/ecore_evas/engines/x/ecore_evas_x.c 
b/src/modules/ecore_evas/engines/x/ecore_evas_x.c
index 2d9c8f9..2d77b13 100644
--- a/src/modules/ecore_evas/engines/x/ecore_evas_x.c
+++ b/src/modules/ecore_evas/engines/x/ecore_evas_x.c
@@ -5011,7 +5011,7 @@ _ecore_evas_x_interface_x11_new(void)
iface-shape_input_rectangle_subtract = 
_ecore_evas_x11_shape_input_rectangle_subtract;
iface-shape_input_empty = _ecore_evas_x11_shape_input_empty;
iface-shape_input_reset = _ecore_evas_x11_shape_input_reset;
-   iface-shape_input_reset = _ecore_evas_x11_shape_input_apply;
+   iface-shape_input_apply = _ecore_evas_x11_shape_input_apply;
 
return iface;
 }

-- 




[EGIT] [core/efl] master 02/02: emile: Fix resource leak

2015-04-20 Thread Christopher Michael
devilhorns pushed a commit to branch master.

http://git.enlightenment.org/core/efl.git/commit/?id=820eca333ecd63eba6d064071741f8b2d86f1dc1

commit 820eca333ecd63eba6d064071741f8b2d86f1dc1
Author: Chris Michael cp.mich...@samsung.com
Date:   Mon Apr 20 13:13:55 2015 -0400

emile: Fix resource leak

Summary: This fixes Coverity CID1288919 where buffer variable was
being leaked if emile failed to load the image due to corrupt file.

@fix

Signed-off-by: Chris Michael cp.mich...@samsung.com
---
 src/lib/emile/emile_image.c | 1 +
 1 file changed, 1 insertion(+)

diff --git a/src/lib/emile/emile_image.c b/src/lib/emile/emile_image.c
index 330bc2f..84589e2 100644
--- a/src/lib/emile/emile_image.c
+++ b/src/lib/emile/emile_image.c
@@ -497,6 +497,7 @@ _emile_tgv_data(Emile_Image *image,
 if (block_length == 0)
   {
  *error = EMILE_IMAGE_LOAD_ERROR_CORRUPT_FILE;
+ eina_binbuf_free(buffer);
  return EINA_FALSE;
   }
 

-- 




[EGIT] [core/efl] master 02/02: ecore-drm: Use #if 0 to comment out unused function

2015-04-20 Thread Christopher Michael
devilhorns pushed a commit to branch master.

http://git.enlightenment.org/core/efl.git/commit/?id=d5005d0efcc96d67209f11cf7b4916e76704e800

commit d5005d0efcc96d67209f11cf7b4916e76704e800
Author: Chris Michael cp.mich...@samsung.com
Date:   Mon Apr 20 12:15:13 2015 -0400

ecore-drm: Use #if 0 to comment out unused function

Summary: It was mentioned on the mailing list to use #if 0 instead of
commenting the block. This does not change any functionality

@fix

Signed-off-by: Chris Michael cp.mich...@samsung.com
---
 src/lib/ecore_drm/ecore_drm_device.c | 2 ++
 1 file changed, 2 insertions(+)

diff --git a/src/lib/ecore_drm/ecore_drm_device.c 
b/src/lib/ecore_drm/ecore_drm_device.c
index e6a5c00..6eaf418 100644
--- a/src/lib/ecore_drm/ecore_drm_device.c
+++ b/src/lib/ecore_drm/ecore_drm_device.c
@@ -86,6 +86,7 @@ _ecore_drm_device_cb_event(void *data, Ecore_Fd_Handler *hdlr 
EINA_UNUSED)
return ECORE_CALLBACK_RENEW;
 }
 
+#if 0
 static Eina_Bool 
 _ecore_drm_device_cb_idle(void *data)
 {
@@ -106,6 +107,7 @@ _ecore_drm_device_cb_idle(void *data)
 
return ECORE_CALLBACK_RENEW;
 }
+#endif
 
 static void
 _ecore_drm_device_cb_output_event(const char *device EINA_UNUSED, 
Eeze_Udev_Event event EINA_UNUSED, void *data, Eeze_Udev_Watch *watch 
EINA_UNUSED)

-- 




[EGIT] [core/enlightenment] master 01/01: use client geometry for starting unmaximize calculations

2015-04-20 Thread Mike Blumenkrantz
discomfitor pushed a commit to branch master.

http://git.enlightenment.org/core/enlightenment.git/commit/?id=934d5417956e4cad9a73dc352c50f63b248ddc33

commit 934d5417956e4cad9a73dc352c50f63b248ddc33
Author: Mike Blumenkrantz zm...@osg.samsung.com
Date:   Mon Apr 20 14:31:27 2015 -0400

use client geometry for starting unmaximize calculations

the resize operations in this function operate off client geometry, so
stop using frame geometry

fix T2170
---
 src/bin/e_client.c | 8 
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/src/bin/e_client.c b/src/bin/e_client.c
index 4952154..ea23a0c 100644
--- a/src/bin/e_client.c
+++ b/src/bin/e_client.c
@@ -3729,10 +3729,10 @@ e_client_unmaximize(E_Client *ec, E_Maximize max)
  int w, h, x, y;
  Eina_Bool horiz = EINA_FALSE, vert = EINA_FALSE;
 
- w = ec-w;
- h = ec-h;
- x = ec-x;
- y = ec-y;
+ w = ec-client.w;
+ h = ec-client.h;
+ x = ec-client.x;
+ y = ec-client.y;
 
  if (((ec-maximized  E_MAXIMIZE_TYPE) == E_MAXIMIZE_SMART) ||
  ((ec-maximized  E_MAXIMIZE_TYPE) == E_MAXIMIZE_EXPAND))

-- 




[EGIT] [website/www-content] master 01/01: Wiki page start changed with summary [Wrapped C++ in nowiki tag (%%C++%%) to prevent possible future issues with inline folding.] by Henrik Danielsson

2015-04-20 Thread Henrik Danielsson
WWW-www.enlightenment.org pushed a commit to branch master.

http://git.enlightenment.org/website/www-content.git/commit/?id=49ed6ff17965e1df3c86b5e860a7f9197cca2117

commit 49ed6ff17965e1df3c86b5e860a7f9197cca2117
Author: Henrik Danielsson h.daniels...@gmail.com
Date:   Mon Apr 20 12:03:16 2015 -0700

Wiki page start changed with summary [Wrapped C++ in nowiki tag (%%C++%%) 
to prevent possible future issues with inline folding.] by Henrik Danielsson
---
 pages/start.txt | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/pages/start.txt b/pages/start.txt
index 0d4fecd..946c614 100644
--- a/pages/start.txt
+++ b/pages/start.txt
@@ -24,7 +24,7 @@ We still primarily support Linux for Enlightenment, but there 
is some effort (ba
 
 In the process of developing a Window Manager, A set of libraries were 
developed in order to achieve that goal. These libraries are known collectively 
as [[:about-efl|EFL]]. They cover a range of functionality from main-loop, to 
graphics, scene graphs, networking, widgets, data storage, IPC and much more.
 
-We now are starting to pull in bindings support directly into EFL. We are 
working on having bindings auto-generated for C++, Lua and Javascript 
(v8/node.js). We also would like to pull in our Python bindings in the future 
so we can support as many languages as possible and keep them up to date.
+We now are starting to pull in bindings support directly into EFL. We are 
working on having bindings auto-generated for %%C++%%, Lua and Javascript 
(v8/node.js). We also would like to pull in our Python bindings in the future 
so we can support as many languages as possible and keep them up to date.
 
 For our libraries, our primary development environment is Linux, but we make 
an effort to support the BSDs as fully as possible, as well as OSX and Windows.
 

-- 




[EGIT] [core/enlightenment] master 01/02: fix clock popup widget parenting

2015-04-20 Thread Mike Blumenkrantz
discomfitor pushed a commit to branch master.

http://git.enlightenment.org/core/enlightenment.git/commit/?id=b842855391e815262639eb616d7ac3b56342cee7

commit b842855391e815262639eb616d7ac3b56342cee7
Author: Mike Blumenkrantz zm...@osg.samsung.com
Date:   Mon Apr 20 15:17:05 2015 -0400

fix clock popup widget parenting
---
 src/modules/clock/e_mod_main.c | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/src/modules/clock/e_mod_main.c b/src/modules/clock/e_mod_main.c
index 6f85720..9e982ec 100644
--- a/src/modules/clock/e_mod_main.c
+++ b/src/modules/clock/e_mod_main.c
@@ -316,9 +316,9 @@ _clock_popup_new(Instance *inst)
inst-popup = e_gadcon_popup_new(inst-gcc, 0);
evas = e_comp-evas;
 
-   inst-o_table = elm_table_add(inst-popup-comp_object);
+   inst-o_table = elm_table_add(e_comp-elm);
 
-   oi = elm_layout_add(inst-popup-comp_object);
+   oi = elm_layout_add(inst-o_table);
inst-o_popclock = oi;
evas_object_size_hint_weight_set(oi, EVAS_HINT_EXPAND, EVAS_HINT_EXPAND);
evas_object_size_hint_align_set(oi, EVAS_HINT_FILL, EVAS_HINT_FILL);
@@ -358,7 +358,7 @@ _clock_popup_new(Instance *inst)
elm_table_pack(inst-o_table, o, 0, 2, 1, 1);
evas_object_show(o);
 
-   oi = elm_layout_add(inst-popup-comp_object);
+   oi = elm_layout_add(inst-o_table);
inst-o_cal = oi;
e_theme_edje_object_set(oi, base/theme/modules/clock,
e/modules/clock/calendar);

-- 




[EGIT] [core/enlightenment] master 01/02: add function for clearing app menu cache

2015-04-20 Thread Mike Blumenkrantz
discomfitor pushed a commit to branch master.

http://git.enlightenment.org/core/enlightenment.git/commit/?id=3eaf4e86387939be5ee1f24ef5e5fc4e277a1fb2

commit 3eaf4e86387939be5ee1f24ef5e5fc4e277a1fb2
Author: Mike Blumenkrantz zm...@osg.samsung.com
Date:   Mon Apr 20 16:04:31 2015 -0400

add function for clearing app menu cache

ref T2271
---
 src/bin/e_int_menus.c | 7 +++
 src/bin/e_int_menus.h | 2 +-
 2 files changed, 8 insertions(+), 1 deletion(-)

diff --git a/src/bin/e_int_menus.c b/src/bin/e_int_menus.c
index e3d41d3..effa5cc 100644
--- a/src/bin/e_int_menus.c
+++ b/src/bin/e_int_menus.c
@@ -499,6 +499,13 @@ e_int_menus_menu_augmentation_del(const char *menu, 
E_Int_Menu_Augmentation *mau
 }
 
 EAPI void
+e_int_menus_cache_clear(void)
+{
+   if (_e_int_menus_app_menus)
+ eina_hash_free_buckets(_e_int_menus_app_menus);
+}
+
+EAPI void
 e_int_menus_menu_augmentation_point_disabled_set(const char *menu, Eina_Bool 
disabled)
 {
if (!menu) return;
diff --git a/src/bin/e_int_menus.h b/src/bin/e_int_menus.h
index 757678c..8af6532 100644
--- a/src/bin/e_int_menus.h
+++ b/src/bin/e_int_menus.h
@@ -84,7 +84,7 @@ EAPI void 
e_int_menus_menu_augmentation_del(const char *menu
 
 EAPI void 
e_int_menus_menu_augmentation_point_disabled_set(const char *menu,
Eina_Bool disabled);
-
+EAPI void e_int_menus_cache_clear(void);
 EINTERN void e_int_menus_init(void);
 EINTERN void e_int_menus_shutdown(void);
 #endif

-- 




[EGIT] [core/enlightenment] enlightenment-0.19 01/03: use client geometry for starting unmaximize calculations

2015-04-20 Thread Mike Blumenkrantz
discomfitor pushed a commit to branch enlightenment-0.19.

http://git.enlightenment.org/core/enlightenment.git/commit/?id=92d8abd38c5719543c58f30aab4e5f52e4f00c51

commit 92d8abd38c5719543c58f30aab4e5f52e4f00c51
Author: Mike Blumenkrantz zm...@osg.samsung.com
Date:   Mon Apr 20 14:31:27 2015 -0400

use client geometry for starting unmaximize calculations

the resize operations in this function operate off client geometry, so
stop using frame geometry

fix T2170
---
 src/bin/e_client.c | 8 
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/src/bin/e_client.c b/src/bin/e_client.c
index 2e96ec2..dc3eb5d 100644
--- a/src/bin/e_client.c
+++ b/src/bin/e_client.c
@@ -3771,10 +3771,10 @@ e_client_unmaximize(E_Client *ec, E_Maximize max)
  int w, h, x, y;
  Eina_Bool horiz = EINA_FALSE, vert = EINA_FALSE;
 
- w = ec-w;
- h = ec-h;
- x = ec-x;
- y = ec-y;
+ w = ec-client.w;
+ h = ec-client.h;
+ x = ec-client.x;
+ y = ec-client.y;
 
  if (((ec-maximized  E_MAXIMIZE_TYPE) == E_MAXIMIZE_SMART) ||
  ((ec-maximized  E_MAXIMIZE_TYPE) == E_MAXIMIZE_EXPAND))

-- 




[EGIT] [core/enlightenment] master 02/02: clear app menu cache any time a desktop is edited internally

2015-04-20 Thread Mike Blumenkrantz
discomfitor pushed a commit to branch master.

http://git.enlightenment.org/core/enlightenment.git/commit/?id=ea7ec93af81af04de380a891013e40d0607de657

commit ea7ec93af81af04de380a891013e40d0607de657
Author: Mike Blumenkrantz zm...@osg.samsung.com
Date:   Mon Apr 20 16:04:48 2015 -0400

clear app menu cache any time a desktop is edited internally

ref T2271
---
 src/bin/e_desktop_editor.c | 1 +
 1 file changed, 1 insertion(+)

diff --git a/src/bin/e_desktop_editor.c b/src/bin/e_desktop_editor.c
index 2e8761f..8a01647 100644
--- a/src/bin/e_desktop_editor.c
+++ b/src/bin/e_desktop_editor.c
@@ -528,6 +528,7 @@ _e_desktop_edit_basic_apply_data(E_Config_Dialog *cfd 
EINA_UNUSED, E_Config_Dial
 cfdata-editor-saved = efreet_desktop_save_as
 (cfdata-desktop, cfdata-orig_path);
  }
+   e_int_menus_cache_clear();
return 1;
 }
 

--
-- 




[EGIT] [core/efl] master 06/06: Evas tests: Add callback_del order test

2015-04-20 Thread Jean-Philippe ANDRÉ
jpeg pushed a commit to branch master.

http://git.enlightenment.org/core/efl.git/commit/?id=d766a765e31dbd3b7b15a55a88210afed089f8ab

commit d766a765e31dbd3b7b15a55a88210afed089f8ab
Author: Jean-Philippe Andre jp.an...@samsung.com
Date:   Mon Apr 20 15:15:34 2015 +0900

Evas tests: Add callback_del order test
---
 src/tests/evas/evas_test_callbacks.c | 19 ++-
 1 file changed, 18 insertions(+), 1 deletion(-)

diff --git a/src/tests/evas/evas_test_callbacks.c 
b/src/tests/evas/evas_test_callbacks.c
index 164851e..f424435 100644
--- a/src/tests/evas/evas_test_callbacks.c
+++ b/src/tests/evas/evas_test_callbacks.c
@@ -70,9 +70,26 @@ START_TEST(evas_object_event_callbacks_priority)
  _obj_event_cb, (void *) 3);
evas_object_move(rect, 3, 3);
 
    /* Make sure we got through all the callbacks */
fail_if(counter != 4);
 
+   /* Verify order of dels (must be reverse order of adds) */
+   counter = 1;
+   evas_object_event_callback_del(rect, EVAS_CALLBACK_MOVE, _obj_event_cb);
+   evas_object_event_callback_del(rect, EVAS_CALLBACK_MOVE, _obj_event_cb);
+   evas_object_event_callback_del(rect, EVAS_CALLBACK_MOVE, _obj_event_cb);
+   evas_object_event_callback_priority_add(rect, EVAS_CALLBACK_MOVE, 10,
+ _obj_event_cb, (void *) 2);
+   evas_object_event_callback_priority_add(rect, EVAS_CALLBACK_MOVE, 0,
+ _obj_event_cb, (void *) 1);
+   evas_object_event_callback_priority_add(rect, EVAS_CALLBACK_MOVE, -10,
+ _obj_event_cb, (void *) 3);
+   evas_object_event_callback_del(rect, EVAS_CALLBACK_MOVE, _obj_event_cb);
+   evas_object_move(rect, 2, 2);
+
+   /* Make sure we got through only the 2 first callbacks (in priority order) 
*/
+   fail_if(counter != 3);
+
END_CALLBACK_TEST();
 }
 END_TEST
@@ -70,9 +70,26 @@ START_TEST(evas_object_event_callbacks_priority)
evas_object_move(rect, 3, 3);
 
-   /* Make sure we got through all the callbacks */
+   /* Make sure we got through all the callbacks in priority order */
fail_if(counter != 4);
 
